@@ -1,20 +1,43 @@
-import { defineMessages, FormattedMessage } from 'react-intl';
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
+import { defineMessages, FormattedMessage, injectIntl } from 'react-intl';
 import { connect } from 'react-redux';
 import ImmutablePropTypes from 'react-immutable-proptypes';
-import { Link } from 'react-router';
+import { Link } from 'react-router-dom';
 import PropTypes from 'prop-types';
 import React from 'react';
+import { Route } from 'react-router-dom';
 
 import { getFilterByName } from '../../selectors/filters';
 import { getFilteredNodes, nodesInProgress } from '../../selectors/nodes';
+import Loader from '../ui/Loader';
 import NodesActions from '../../actions/NodesActions';
 import NodesListForm from './NodesListView/NodesListForm';
 import NodesListView from './NodesListView/NodesListView';
 import NodesToolbar from './NodesToolbar/NodesToolbar';
 import NodesTableView from './NodesTableView';
+import RegisterNodesDialog from './RegisterNodesDialog';
 import RolesActions from '../../actions/RolesActions';
 
 const messages = defineMessages({
+  loadingNodes: {
+    id: 'Nodes.loadingNodes',
+    defaultMessage: 'Loading Nodes...'
+  },
   refreshResults: {
     id: 'Nodes.refreshResults',
     defaultMessage: 'Refresh Results'
@@ -57,13 +80,20 @@ class Nodes extends React.Component {
       <div>
         <div className="page-header">
           <div className="pull-right">
-            <a
-              className="link btn btn-link"
-              onClick={this.refreshResults.bind(this)}
+            <Loader
+              loaded={!(this.props.fetchingNodes && this.props.nodesLoaded)}
+              content={this.props.intl.formatMessage(messages.loadingNodes)}
+              component="span"
+              inline
             >
-              <span className="pficon pficon-refresh" />&nbsp;
-              <FormattedMessage {...messages.refreshResults} />
-            </a>
+              <a
+                className="link btn btn-link"
+                onClick={this.refreshResults.bind(this)}
+              >
+                <span className="pficon pficon-refresh" />&nbsp;
+                <FormattedMessage {...messages.refreshResults} />
+              </a>
+            </Loader>
             &nbsp;
             <Link to="/nodes/register" className="btn btn-primary">
               <span className="fa fa-plus" />&nbsp;
@@ -72,21 +102,29 @@ class Nodes extends React.Component {
           </div>
           <h1><FormattedMessage {...messages.nodes} /></h1>
         </div>
-        <NodesToolbar />
-        {this.renderContentView()}
-        {this.props.children}
+        <Loader
+          loaded={this.props.nodesLoaded}
+          content={this.props.intl.formatMessage(messages.loadingNodes)}
+          height={80}
+        >
+          <NodesToolbar />
+          {this.renderContentView()}
+        </Loader>
+        <Route path="/nodes/register" component={RegisterNodesDialog} />
       </div>
     );
   }
 }
 Nodes.propTypes = {
-  children: PropTypes.node,
   contentView: PropTypes.string.isRequired,
   currentPlanName: PropTypes.string.isRequired,
   fetchNodes: PropTypes.func.isRequired,
   fetchRoles: PropTypes.func.isRequired,
+  fetchingNodes: PropTypes.bool.isRequired,
+  intl: PropTypes.object.isRequired,
   nodes: ImmutablePropTypes.map.isRequired,
-  nodesInProgress: ImmutablePropTypes.set.isRequired
+  nodesInProgress: ImmutablePropTypes.set.isRequired,
+  nodesLoaded: PropTypes.bool.isRequired
 };
 
 const mapStateToProps = state => ({
@@ -95,8 +133,10 @@ const mapStateToProps = state => ({
     'list'
   ),
   currentPlanName: state.currentPlan.currentPlanName,
+  fetchingNodes: state.nodes.get('isFetching'),
   nodes: getFilteredNodes(state),
-  nodesInProgress: nodesInProgress(state)
+  nodesInProgress: nodesInProgress(state),
+  nodesLoaded: state.nodes.get('isLoaded')
 });
 
 const mapDispatchToProps = dispatch => ({
@@ -105,4 +145,4 @@ const mapDispatchToProps = dispatch => ({
     dispatch(RolesActions.fetchRoles(currentPlanName))
 });
 
-export default connect(mapStateToProps, mapDispatchToProps)(Nodes);
+export default injectIntl(connect(mapStateToProps, mapDispatchToProps)(Nodes));
