@@ -1,14 +1,29 @@
-import { fromJS, Map, Set } from 'immutable';
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
+import { fromJS, Map } from 'immutable';
 
 import NodesConstants from '../constants/NodesConstants';
-import { Port } from '../immutableRecords/nodes';
+import {
+  NodesState,
+  Port,
+  IntrospectionStatus
+} from '../immutableRecords/nodes';
 
-const initialState = Map({
-  isFetching: false,
-  nodesInProgress: Set(),
-  all: Map(),
-  ports: Map()
-});
+const initialState = new NodesState();
 
 export default function nodesReducer(state = initialState, action) {
   switch (action.type) {
@@ -16,10 +31,15 @@ export default function nodesReducer(state = initialState, action) {
       return state.set('isFetching', true);
 
     case NodesConstants.RECEIVE_NODES: {
-      const { nodes, ports } = action.payload;
+      const { nodes, ports, introspectionStatuses } = action.payload;
       return state
         .set('all', fromJS(nodes || {}))
         .set('ports', Map(ports).map(port => new Port(port)))
+        .set(
+          'introspectionStatuses',
+          Map(introspectionStatuses).map(s => new IntrospectionStatus(s))
+        )
+        .set('isLoaded', true)
         .set('isFetching', false);
     }
 
